summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-11-01 18:45:35 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-11-01 18:59:15 -0500
commitbd3818eb1bde3f7400f50d6bfdb118ecbab19d13 (patch)
tree96d967becb1e2a29e09f781ec31e25f76393d2aa /png.h
parentb75c3cc4156d5396805af42a0430a8773f86d42a (diff)
downloadlibpng-bd3818eb1bde3f7400f50d6bfdb118ecbab19d13.tar.gz
[libpng16] Bump version to 1.6.15beta03
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 141c651a6..31c812fae 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.15beta02 - November 1, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.15beta02 - November 1, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -206,7 +206,7 @@
* 1.6.14beta01-07 16 10614 16.so.16.14[.0]
* 1.6.14rc01-02 16 10614 16.so.16.14[.0]
* 1.6.14 16 10614 16.so.16.14[.0]
- * 1.6.15beta01-02 16 10615 16.so.16.15[.0]
+ * 1.6.15beta01-03 16 10615 16.so.16.15[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -238,7 +238,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.15beta02, November 1, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -356,7 +356,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.15beta02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -418,9 +418,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.15beta02"
+#define PNG_LIBPNG_VER_STRING "1.6.15beta03"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.15beta02 - November 1, 2014\n"
+ " libpng version 1.6.15beta03 - November 1, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -434,7 +434,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 02
+#define PNG_LIBPNG_VER_BUILD 03
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -564,7 +564,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_15beta02;
+typedef char* png_libpng_version_1_6_15beta03;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.15beta02 - November 1, 2014
+ * libpng version 1.6.15beta03 - November 1, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.15beta02 - November 1, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.15beta03 - November 1, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -238,7 +238,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.15beta02, November 1, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.15beta03, November 1, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -356,7 +356,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.15beta02 are Y2K compliant. It is my belief that
+ * upward through 1.6.15beta03 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*